[# Stage Model YAML Schema Template #]
version: 2

models:
  - name: [[ stage_name ]]
    description: "Staging model for [[ source_table ]] from [[ source_system ]]"
    config:
      tags: ['staging', '[[ source_system | lower | replace(" ", "_") ]]']
    columns:
      - name: rsrc
        description: "Record source identifier"
      - name: ldts
        description: "Load date timestamp"
[% for hashkey in hashkeys %]
      - name: [[ hashkey.hashkey_name ]]
        description: "Hash key"
[% endfor %]
[% for hashdiff in hashdiffs %]
      - name: [[ hashdiff.hashdiff_name ]]
        description: "Hash diff for [[ hashdiff.satellite_name ]]"
[% endfor %]
