# Generated by Django 6.0 on 2026-02-17 11:59

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engine', '0003_remove_linkhubsourcemapping_prejoin_extraction_column_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='hubsourcemapping',
            name='staging_column',
            field=models.ForeignKey(blank=True, help_text='Unified staging column for this hub mapping', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='hub_mappings', to='engine.stagingcolumn'),
        ),
        migrations.AddField(
            model_name='linksourcemapping',
            name='staging_column',
            field=models.ForeignKey(blank=True, help_text='Unified staging column for this link mapping', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='link_column_mappings', to='engine.stagingcolumn'),
        ),
        migrations.AddField(
            model_name='satellitecolumn',
            name='staging_column',
            field=models.ForeignKey(blank=True, help_text='Unified staging column for this satellite column', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='satellite_columns', to='engine.stagingcolumn'),
        ),
        migrations.AlterField(
            model_name='hubsourcemapping',
            name='source_column',
            field=models.ForeignKey(blank=True, help_text='Source column providing the data (legacy)', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='hub_mappings', to='engine.sourcecolumn'),
        ),
        migrations.AlterField(
            model_name='linksourcemapping',
            name='source_column',
            field=models.ForeignKey(blank=True, help_text='Source column mapped to this link column (legacy)', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='link_column_mappings', to='engine.sourcecolumn'),
        ),
        migrations.AlterField(
            model_name='satellitecolumn',
            name='source_column',
            field=models.ForeignKey(blank=True, help_text='Source column providing the data (legacy)', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='satellite_columns', to='engine.sourcecolumn'),
        ),
    ]
