# Generated by Django 6.0 on 2026-02-17 11:22

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engine', '0002_stagingcolumn_linkhubsourcemapping_staging_column'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='linkhubsourcemapping',
            name='prejoin_extraction_column',
        ),
        migrations.RemoveField(
            model_name='linkhubsourcemapping',
            name='source_column',
        ),
        migrations.AlterField(
            model_name='linkhubsourcemapping',
            name='staging_column',
            field=models.ForeignKey(default=1, help_text='Unified staging column for this hub key mapping', on_delete=django.db.models.deletion.CASCADE, related_name='link_hub_mappings', to='engine.stagingcolumn'),
            preserve_default=False,
        ),
    ]
