[# Snapshot Control V0 Model YAML Schema Template #]
version: 2

models:
  - name: [[ name ]]_v0
    description: "Snapshot control table (base configuration)"
    config:
      tags: ['snapshot_control', 'control']
    columns:
      - name: sdts
        description: "Snapshot date timestamp"
        data_tests:
          - unique
          - not_null
