[# Reference Table Model YAML Schema Template #]
version: 2

models:
  - name: [[ table_name ]]
    description: "Reference table combining [[ reference_hub_name ]] with satellites"
    config:
      tags: ['reference_table', 'business_vault']
