# Generated by Django 6.0 on 2026-02-19 16:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("engine", "0005_alter_satellitecolumn_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="project",
            name="project_directory",
            field=models.CharField(
                blank=True,
                help_text="Relative path to project directory (e.g., 'projects/customer_mdm')",
                max_length=512,
                null=True,
            ),
        ),
    ]
