[# Satellite Model YAML Schema Template #]
version: 2

models:
  - name: [[ satellite_name ]]
    description: "[[ satellite_type | title ]] satellite for [[ parent_entity ]]"
    config:
      tags: ['satellite', '[[ satellite_type ]]', 'raw_vault'[% if group %], '[[ group ]]'[% endif %]]
    columns:
      - name: [[ parent_hashkey ]]
        description: "Parent entity hash key"
        data_tests:
          - not_null
      - name: [[ hashdiff_name ]]
        description: "Hash diff for change detection"
[% for column in columns %]
      - name: [[ column.target_column_name if column.target_column_name else column.source_column ]]
        description: "Payload column"
[% endfor %]
      - name: ldts
        description: "Load date timestamp"
      - name: rsrc
        description: "Record source"
