[# Effectivity Satellite Template #]
[# Tracks the effectivity (active/inactive status) of relationships #]
{{ config(
    materialized='incremental',
    tags=['satellite', 'effectivity', 'raw_vault'[% if group %], '[[ group ]]'[% endif %]]
) }}

{%- set yaml_metadata -%}
source_model: [[ stage_name ]]
tracked_hashkey: [[ parent_hashkey ]]
{%- endset -%}

{{ datavault4dbt.eff_sat_v0(yaml_metadata=yaml_metadata) }}
