# Generated by Django 6.0 on 2026-02-17 12:01

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engine', '0004_hubsourcemapping_staging_column_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='satellitecolumn',
            options={'ordering': ['satellite', 'staging_column']},
        ),
        migrations.AlterUniqueTogether(
            name='hubsourcemapping',
            unique_together={('hub_column', 'staging_column')},
        ),
        migrations.RemoveField(
            model_name='linksourcemapping',
            name='source_column',
        ),
        migrations.AlterUniqueTogether(
            name='satellitecolumn',
            unique_together={('satellite', 'staging_column')},
        ),
        migrations.AlterField(
            model_name='hubsourcemapping',
            name='staging_column',
            field=models.ForeignKey(default='00000000-0000-0000-0000-000000000000', help_text='Unified staging column for this hub mapping', on_delete=django.db.models.deletion.CASCADE, related_name='hub_mappings', to='engine.stagingcolumn'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='linksourcemapping',
            name='staging_column',
            field=models.ForeignKey(default='00000000-0000-0000-0000-000000000000', help_text='Unified staging column for this link mapping', on_delete=django.db.models.deletion.CASCADE, related_name='link_column_mappings', to='engine.stagingcolumn'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='satellitecolumn',
            name='staging_column',
            field=models.ForeignKey(default='00000000-0000-0000-0000-000000000000', help_text='Unified staging column for this satellite column', on_delete=django.db.models.deletion.CASCADE, related_name='satellite_columns', to='engine.stagingcolumn'),
            preserve_default=False,
        ),
        migrations.RemoveField(
            model_name='hubsourcemapping',
            name='source_column',
        ),
        migrations.RemoveField(
            model_name='satellitecolumn',
            name='source_column',
        ),
    ]
